@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 SchoolTool flourish pages.
@@ -25,7 +24,7 @@ import urllib
 
 from zope.cachedescriptors.property import Lazy
 from zope.component import getMultiAdapter, queryMultiAdapter
-from zope.interface import implements
+from zope.interface import implements, Interface
 from zope.publisher.browser import BrowserPage
 from zope.publisher.interfaces import NotFound
 from zope.browser.interfaces import IBrowserView
